@@ -76,6 +76,8 @@ __all__ = (
     "DeleteTypeRequestRequestTypeDef",
     "DeltaSyncConfigTypeDef",
     "DisassociateApiRequestRequestTypeDef",
+    "ErrorDetailTypeDef",
+    "EvaluateMappingTemplateRequestRequestTypeDef",
     "FlushApiCacheRequestRequestTypeDef",
     "GetApiAssociationRequestRequestTypeDef",
     "GetApiCacheRequestRequestTypeDef",
@@ -129,6 +131,7 @@ __all__ = (
     "ListTypesResponseTypeDef",
     "UpdateTypeResponseTypeDef",
     "DynamodbDataSourceConfigTypeDef",
+    "EvaluateMappingTemplateResponseTypeDef",
     "SyncConfigTypeDef",
     "ListApiKeysRequestListApiKeysPaginateTypeDef",
     "ListDataSourcesRequestListDataSourcesPaginateTypeDef",
@@ -300,15 +303,25 @@ AwsIamConfigTypeDef = TypedDict(
     total=False,
 )
 
-CachingConfigTypeDef = TypedDict(
-    "CachingConfigTypeDef",
+_RequiredCachingConfigTypeDef = TypedDict(
+    "_RequiredCachingConfigTypeDef",
     {
         "ttl": int,
+    },
+)
+_OptionalCachingConfigTypeDef = TypedDict(
+    "_OptionalCachingConfigTypeDef",
+    {
         "cachingKeys": Sequence[str],
     },
     total=False,
 )
 
+
+class CachingConfigTypeDef(_RequiredCachingConfigTypeDef, _OptionalCachingConfigTypeDef):
+    pass
+
+
 _RequiredCreateApiCacheRequestRequestTypeDef = TypedDict(
     "_RequiredCreateApiCacheRequestRequestTypeDef",
     {
@@ -562,6 +575,22 @@ DisassociateApiRequestRequestTypeDef = TypedDict(
     },
 )
 
+ErrorDetailTypeDef = TypedDict(
+    "ErrorDetailTypeDef",
+    {
+        "message": str,
+    },
+    total=False,
+)
+
+EvaluateMappingTemplateRequestRequestTypeDef = TypedDict(
+    "EvaluateMappingTemplateRequestRequestTypeDef",
+    {
+        "template": str,
+        "context": str,
+    },
+)
+
 FlushApiCacheRequestRequestTypeDef = TypedDict(
     "FlushApiCacheRequestRequestTypeDef",
     {
@@ -1173,6 +1202,15 @@ class DynamodbDataSourceConfigTypeDef(
     pass
 
 
+EvaluateMappingTemplateResponseTypeDef = TypedDict(
+    "EvaluateMappingTemplateResponseTypeDef",
+    {
+        "evaluationResult": str,
+        "error": ErrorDetailTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 SyncConfigTypeDef = TypedDict(
     "SyncConfigTypeDef",
     {
